abacusai.type_violation — AbacusAI documentation

# `abacusai.type_violation`

## Module Contents

### Classes

`TypeViolation` | Summary of important type mismatches for a feature discovered by a model monitoring instance

class abacusai.type_violation.TypeViolation(client, name=None, trainingDataType=None, predictionDataType=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Summary of important type mismatches for a feature discovered by a model monitoring instance

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - trainingDataType (str) – Data type of training feature that doesn’t match the type of the corresponding prediction feature.

    - predictionDataType (str) – Data type of prediction feature that doesn’t match the type of the corresponding training feature.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict